<h1 align="center">
    <img src="https://github.com/2003100127/drutai/blob/main/docs/img/drutai-logo.png?raw=true" width="200" height="55">
    <br>
</h1>

<hr>

![PyPI](https://img.shields.io/pypi/v/drutai?logo=PyPI)
[![Downloads](https://pepy.tech/badge/drutai)](https://pepy.tech/project/drutai)
![](https://img.shields.io/github/stars/2003100127/drutai?logo=GitHub&color=blue)

## 💻 Platform

![Python](https://img.shields.io/badge/-Python-000?&logo=Python)
![PyPI](https://img.shields.io/badge/-PyPI-000?&logo=PyPI)

## 🧭 Overview
Drutai is a deep learning–based framework for predicting interactions between small molecule drugs and protein targets. It gains high accuracy due to its integration of multiple deep learning methods and informative features.

> Whether you’re working in computational drug discovery, bioinformatics, or molecular pharmacology, Drutai provides a ready-to-use solution for high-accuracy DTI prediction.

## 📔 Documentation
Please check https://2003100127.github.io/drutai for its usage.

## 🛠️ Installation

* ![PyPI](https://img.shields.io/badge/-PyPI-000?&logo=PyPI) (https://pypi.org/project/drutai)

  ``` shell
  conda create --name drutai python=3.11
      
  conda activate drutai
  
  pip install drutai --upgrade
  ```

## 📚 Citation

```shell!
Sun, J., Xu, M., Ru, J., James-Bott, A., Xiong, D., Wang, X., & Cribbs, A. P. (2023). Small molecule-mediated targeting of microRNAs for drug discovery: Experiments, computational techniques, and disease implications. European journal of medicinal chemistry, 257, 115500. https://doi.org/10.1016/j.ejmech.2023.115500
```

```markdown
@article{Sun2023,
    title = {Small molecule-mediated targeting of microRNAs for drug discovery: Experiments, computational techniques, and disease implications},
    author = {Jianfeng Sun and Miaoer Xu and Jinlong Ru and Anna James-Bott and Dapeng Xiong and Xia Wang and Adam P. Cribbs},
    journal = {European Journal of Medicinal Chemistry},
    volume = {257},
    pages = {115500},
    year = {2023},
    issn = {0223-5234},
    doi = {https://doi.org/10.1016/j.ejmech.2023.115500},
    url = {https://www.sciencedirect.com/science/article/pii/S022352342300466X},
    keywords = {microRNA targets, Drug discovery, Molecular interactions, Disease implications, Deep learning},
}
```

## 🏠 Developer
[Jianfeng Sun](https://www.2003100127.github.io) 

## 📧 Contact
[![Linkedin Badge](https://img.shields.io/badge/-Jianfeng_Sun-blue?style=flat-square&logo=Linkedin&logoColor=white&link=https://www.linkedin.com/in/jianfeng-sun-2ba9b1132)](https://www.linkedin.com/in/jianfeng-sun-2ba9b1132) 
[![Gmail Badge](https://img.shields.io/badge/-jianfeng.sunmt@gmail.com-c14438?style=flat-square&logo=Gmail&logoColor=white&link=mailto:jianfeng.sunmt@gmail.com)](mailto:jianfeng.sunmt@gmail.com)
[![Outlook Badge](https://img.shields.io/badge/jianfeng.sun@ndorms.ox.ac.uk--000?style=social&logo=microsoft-outlook&logoColor=0078d4&link=mailto:jianfeng.sun@ndorms.ox.ac.uk)](mailto:jianfeng.sun@ndorms.ox.ac.uk)
<a href="https://twitter.com/Jianfeng_Sunny" ><img src="https://img.shields.io/twitter/follow/Jianfeng_Sunny.svg?style=social" /></a>